jose.jwks


find-keyclj

(find-key source-value kid)

Returns the first key with kid, or nil.

Returns the first key with kid, or nil.
sourceraw docstring

get-keysclj

(get-keys source-value opts)

Returns Nimbus JWKs matching the supplied JWK matcher options.

Returns Nimbus JWKs matching the supplied JWK matcher options.
sourceraw docstring

local-sourceclj

(local-source jwk-set-or-vector)

Returns an opaque in-memory JWKS source.

Returns an opaque in-memory JWKS source.
sourceraw docstring

matcherclj

(matcher opts)

Builds a Nimbus JWKMatcher from matcher options.

Builds a Nimbus JWKMatcher from matcher options.
sourceraw docstring

remote-sourceclj

(remote-source jwks-url)
(remote-source jwks-url opts)

Returns an opaque remote JWKS source.

Without options, Nimbus defaults are used. Options configure caching, refresh-ahead, retry, failover, outage tolerance, rate limiting, and event or health listeners.

Returns an opaque remote JWKS source.

Without options, Nimbus defaults are used. Options configure caching,
refresh-ahead, retry, failover, outage tolerance, rate limiting, and event
or health listeners.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries