jose.mint


jwk-sourceclj

(jwk-source minter-value)

Returns the underlying Nimbus JWKSource configured on a minter.

Returns the underlying Nimbus JWKSource configured on a minter.
sourceraw docstring

mintclj

(mint minter-value payload-value)
(mint minter-value payload-value opts)

Mints a compact JWS after Nimbus selects a signing key from the source.

Mints a compact JWS after Nimbus selects a signing key from the source.
sourceraw docstring

minterclj

(minter source-value)
(minter source-value opts)

Creates an opaque Nimbus JWS minter backed by a JWKS source.

Creates an opaque Nimbus JWS minter backed by a JWKS source.
sourceraw docstring

signer-factoryclj

(signer-factory minter-value)

Returns the Nimbus signer factory configured on a minter.

Returns the Nimbus signer factory configured on a minter.
sourceraw docstring

sourceclj

(source minter-value)

Returns the source value configured on a minter.

Returns the source value configured on a minter.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries