jose.jwk


->jsonclj

(->json jwk)
(->json jwk opts)

Returns a JWK JSON string. Pass {:private? false} for a public-only JWK.

Returns a JWK JSON string. Pass {:private? false} for a public-only JWK.
sourceraw docstring

->mapclj

(->map jwk)

Returns the complete JWK JSON representation as a Clojure map.

Returns the complete JWK JSON representation as a Clojure map.
sourceraw docstring

find-keyclj

(find-key jwks kid)
source

generateclj

(generate kind)
(generate kind opts)

Generates a Nimbus JWK. Kind is one of :rsa, :ec, :okp, or :oct.

Generates a Nimbus JWK. Kind is one of :rsa, :ec, :okp, or :oct.
sourceraw docstring

jwk-setclj

(jwk-set jwks)
source

key-idclj

(key-id jwk)
source

key-typeclj

(key-type jwk)
source

parseclj

(parse s-or-map)

Parses a JWK JSON string, Clojure map, or returns a Nimbus JWK unchanged.

Parses a JWK JSON string, Clojure map, or returns a Nimbus JWK unchanged.
sourceraw docstring

parse-setclj

(parse-set s-or-map)

Parses a JWKS JSON string, Clojure map, or returns a Nimbus JWKSet unchanged.

Parses a JWKS JSON string, Clojure map, or returns a Nimbus JWKSet unchanged.
sourceraw docstring

private?clj

(private? jwk)
source

public-jwkclj

(public-jwk jwk)

Returns a public-only JWK, or nil when the key has no public form.

Returns a public-only JWK, or nil when the key has no public form.
sourceraw docstring

set->jsonclj

(set->json jwks)
(set->json jwks opts)
source

set->mapsclj

(set->maps jwks)
source

thumbprintclj

(thumbprint jwk)

Returns the RFC 7638 SHA-256 JWK thumbprint.

Returns the RFC 7638 SHA-256 JWK thumbprint.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries