(->json jwk)(->json jwk opts)Returns a JWK JSON string. Pass {:private? false} for a public-only JWK.
Returns a JWK JSON string. Pass {:private? false} for a public-only JWK.
(->map jwk)Returns the complete JWK JSON representation as a Clojure map.
Returns the complete JWK JSON representation as a Clojure map.
(generate kind)(generate kind opts)Generates a Nimbus JWK. Kind is one of :rsa, :ec, :okp, or :oct.
Generates a Nimbus JWK. Kind is one of :rsa, :ec, :okp, or :oct.
(parse s-or-map)Parses a JWK JSON string, Clojure map, or returns a Nimbus JWK unchanged.
Parses a JWK JSON string, Clojure map, or returns a Nimbus JWK unchanged.
(parse-set s-or-map)Parses a JWKS JSON string, Clojure map, or returns a Nimbus JWKSet unchanged.
Parses a JWKS JSON string, Clojure map, or returns a Nimbus JWKSet unchanged.
(public-jwk jwk)Returns a public-only JWK, or nil when the key has no public form.
Returns a public-only JWK, or nil when the key has no public form.
(thumbprint jwk)Returns the RFC 7638 SHA-256 JWK thumbprint.
Returns the RFC 7638 SHA-256 JWK thumbprint.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |