(find-key source-value kid)Returns the first key with kid, or nil.
Returns the first key with kid, or nil.
(get-keys source-value opts)Returns Nimbus JWKs matching the supplied JWK matcher options.
Returns Nimbus JWKs matching the supplied JWK matcher options.
(local-source jwk-set-or-vector)Returns an opaque in-memory JWKS source.
Returns an opaque in-memory JWKS source.
(matcher opts)Builds a Nimbus JWKMatcher from matcher options.
Builds a Nimbus JWKMatcher from matcher options.
(remote-source jwks-url)(remote-source jwks-url opts)Returns an opaque remote JWKS source.
Without options, Nimbus defaults are used. Options configure caching, refresh-ahead, retry, failover, outage tolerance, rate limiting, and event or health listeners.
Returns an opaque remote JWKS source. Without options, Nimbus defaults are used. Options configure caching, refresh-ahead, retry, failover, outage tolerance, rate limiting, and event or health listeners.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |