(header compact)Returns the unverified compact JWS header as a Clojure map.
Returns the unverified compact JWS header as a Clojure map.
(sign key payload-value)(sign key payload-value opts)Signs a string or byte-array payload and returns a compact JWS string.
Signs a string or byte-array payload and returns a compact JWS string.
(verify key compact)(verify key compact opts)Verifies a compact JWS and returns {:payload string :payload-bytes bytes :header map}.
:alg or :algs is required and constrains accepted algorithms. :typ and :cty require matching headers. :crit names understood critical headers. Pass {:algs :any} to unsafely accept any signed algorithm supported by the key. alg:none is always rejected.
Verifies a compact JWS and returns {:payload string :payload-bytes bytes :header map}.
:alg or :algs is required and constrains accepted algorithms. :typ and :cty
require matching headers. :crit names understood critical headers. Pass
{:algs :any} to unsafely accept any signed algorithm supported by the key.
alg:none is always rejected.(verify-detached key compact payload)(verify-detached key compact payload opts)Verifies a detached compact JWS with an out-of-band payload.
Accepts the same required algorithm policy and optional header policy as verify.
Verifies a detached compact JWS with an out-of-band payload. Accepts the same required algorithm policy and optional header policy as verify.
(verify-with-jwks source compact)(verify-with-jwks source compact opts)Selects a verification key from a JWKS source, then verifies a compact JWS.
Selects a verification key from a JWKS source, then verifies a compact JWS.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |