(decrypt ring compact)Decrypts with the header kid first, then falls back across retained keys.
Decrypts with the header kid first, then falls back across retained keys.
(encrypt ring payload)(encrypt ring payload opts)Encrypts with the active encryption key.
Encrypts with the active encryption key.
(key-ring keys opts)Creates an immutable key ring from JWKs and active signing/encryption kids.
Creates an immutable key ring from JWKs and active signing/encryption kids.
(prune ring opts)Drops non-active keys retired before the configured retention window.
Drops non-active keys retired before the configured retention window.
(public-jwks ring)Returns a Nimbus JWKSet containing only public key material.
Returns a Nimbus JWKSet containing only public key material.
(public-jwks-json ring)Returns the public key ring as JWKS JSON suitable for publication.
Returns the public key ring as JWKS JSON suitable for publication.
(rotate ring role key)(rotate ring role key opts)Promotes a new active key for :signing or :encryption and retains the old key.
Promotes a new active key for :signing or :encryption and retains the old key.
(sign ring payload)(sign ring payload opts)Signs with the active signing key.
Signs with the active signing key.
(verify ring compact)(verify ring compact opts)Verifies with the header kid first, then falls back across retained keys.
Verifies with the header kid first, then falls back across retained keys.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |