(jwk-source minter-value)Returns the underlying Nimbus JWKSource configured on a minter.
Returns the underlying Nimbus JWKSource configured on a minter.
(mint minter-value payload-value)(mint minter-value payload-value opts)Mints a compact JWS after Nimbus selects a signing key from the source.
Mints a compact JWS after Nimbus selects a signing key from the source.
(minter source-value)(minter source-value opts)Creates an opaque Nimbus JWS minter backed by a JWKS source.
Creates an opaque Nimbus JWS minter backed by a JWKS source.
(signer-factory minter-value)Returns the Nimbus signer factory configured on a minter.
Returns the Nimbus signer factory configured on a minter.
(source minter-value)Returns the source value configured on a minter.
Returns the source value configured on a minter.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |